"""Test cases for ``Variance`` extension.

Uses shared test cases from `test.extensions.firstorder.firstorder_settings`,
and the local cases defined in this file.
"""
from test.extensions.firstorder.firstorder_settings import FIRSTORDER_SETTINGS

SHARED_SETTINGS = FIRSTORDER_SETTINGS
LOCAL_SETTINGS = []

VARIANCE_SETTINGS = SHARED_SETTINGS + LOCAL_SETTINGS
